/* Eclipse Projekt for Yagarto
 * Prozessor: Kinetics MK60N512VMD100
 * Tested on: Freescale Tower System
 *
 * Author: David Thiesbrummel (www.david-th.de)
 * Student at Georg-Simon-Ohm Hochschule, Germany (www.ohm-hochschule.de)
 * Date: 27.04.2012
 * Status: running
 * 
 * Init and using the PIT (periodic interrupt timer)
 * Flashing all 4 LEDs to show the working PIT
 */

#include <stdio.h>
#include "MK60N512VMD100.h"  /* include peripheral declarations */

#define __SP_INIT 0x20001000
#define UNASSIGNED_ISR isr_default   /* unassigned interrupt service routine */

//Function declarations
int main(void);
void port_init_K60(void);
void PIT0_Init (void);
void PIT_CH0_INT(void);
void isrINT_NMI(void);
void isr_default(void);
void isr_hard_fault(void);
void isr_bus_error(void);
void isr_usage_fault(void);
void isr_error(void);

void __init_hardware(void);
void MCU_init(void);

extern uint32_t __vector_table[];		// from Linker Command File

int main(void)
{
	__init_hardware();
	/* Initialize GPIO on TWR-K60N512 */
	port_init_K60();
	//pit periodic interrupt timer init
	PIT0_Init ();

	GPIOA_PDOR &= 0xCFFFF3FF;	// all LEDs on

    while(1) {
    	//wait for interrupt
    }
	return 0;
}


void port_init_K60()
{
  //PORTA_PAR: Set PTA10, PTA11, PTA28, and PTA29 (connected to LEDs) for GPIO functionality
  PORTA_PCR10=(0|PORT_PCR_MUX(1));
  PORTA_PCR11=(0|PORT_PCR_MUX(1));
  PORTA_PCR28=(0|PORT_PCR_MUX(1));
  PORTA_PCR29=(0|PORT_PCR_MUX(1));

  //Change PTA10, PTA11, PTA28, PTA29 to outputs
//  GPIOA_PDDR=GPIO_PDDR_PDD(GPIO_PIN(10) | GPIO_PIN(11) | GPIO_PIN(28) | GPIO_PIN(29) );	
  GPIOA_PDDR=0x30000C00;	//all LEDs off
}

void PIT0_Init (void)
{

  SIM_SCGC6 |= (uint32_t)(1<<23);     /* Enable clock gate for PIT */

  // Enable PIT0 interrupt in the Nested Vector Interrupt Controller (NVIC_ISER2, Bit 4)
  NVICISER2 |= (uint32_t)0x10UL;

  // Set priority of PIT0 interrupt to 9 in the Nested Vector Interrupt Controller (NVIC_IPR17, Bits 4 - 7)
  NVICIP68 = (uint8_t)0x00U;

  /* PIT_Module Control Register: MDIS=0,FRZ=0 (Clock for PIT is enabled, Timers continue to run in debug mode)*/
  PIT_MCR = (uint32_t)0x00UL;
  /* PIT Timer Load Value Register 0: Timer Start Value=0x00BEBC1F; LDVAL =(Period/clock period) - 1; i.e. LDVAL = (0,5s/40ns) - 1 = 12499999 = 0xBEBC1F at 25 MHz clock*/
  PIT_LDVAL0 = (uint32_t)0x00BEBC1FUL; //timer 0 for 25000000 cycles;
  /* PIT Timer Control Register 0: TIE=1,TEN=0 (Timer 0 Interrupt enabled, Timer 0 disabled)*/
  PIT_TCTRL0 = (uint32_t)0x02UL;
  /* PIT Timer Flag Register 0: TIF=1 (Clear Timer Interrupt Flag 0)*/
  PIT_TFLG0 = (uint32_t)0x01UL;
  /* PIT_TCTRL0: TEN=1 (Enable Timer 0)*/
  PIT_TCTRL0 |= (uint32_t)0x01UL;
  /* PIT_MCR: MDIS=1 (Clock for PIT is disabled)*/
 // PIT_MCR |= (uint32_t)0x02UL;
}

void PIT_CH0_INT(void)
{
	// Toggle all LEDs
    GPIOA_PDOR ^= 0x30000C00;

// NOTE: The routine should include actions to clear the appropriate
//       interrupt flags.
//
    /* PIT Timer Control Register 0: TIE=1,TEN=0 (Timer 0 Interrupt enabled, Timer 0 disabled)*/
    PIT_TCTRL0 = (uint32_t)0x02UL;
    /* PIT Timer Flag Register 0: TIF=1 (Clear Timer Interrupt Flag 0)*/
    PIT_TFLG0 = (uint32_t)0x01UL;
    /* PIT_TCTRL0: TEN=1 (Enable Timer 0)*/
    PIT_TCTRL0 |= (uint32_t)0x01UL;



}

/*
** ===================================================================
**     Interrupt handler : isr_default
**
**     Description :
**         User interrupt service routine.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void isr_default(void)
{
  /* Write your interrupt code here ... */
	GPIOA_PDOR |= 0x30000C00;   // all LEDs off
}
/* end of isr_default */

/*
** ===================================================================
**     Interrupt handler : isr_error
**
**     Description :
**         Interrupt service routine for the first 16 error interrupts.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void isr_hard_fault(void)
{
  /* Write your interrupt code here ... */
	GPIOA_PDOR |= 0x30000C00;   // all LEDs off
}
/* end of isr_error */
/*
** ===================================================================
**     Interrupt handler : isr_error
**
**     Description :
**         Interrupt service routine for hard fault.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void isr_error(void)
{
  /* Write your interrupt code here ... */
	GPIOA_PDOR |= 0x30000C00;   // all LEDs off
}
/* end of isr_hard_fault */

/*
** ===================================================================
**     Interrupt handler : isr_bus_error
**
**     Description :
**         Interrupt service routine for bus error.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void isr_bus_error(void)
{
  /* Write your interrupt code here ... */
	GPIOA_PDOR |= 0x30000C00;   // all LEDs off
}
/* end of isr_bus_error */
/*
** ===================================================================
**     Interrupt handler : isr_usage_fault
**
**     Description :
**         Interrupt service routine for usage fault.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void isr_usage_fault(void)
{
  /* Write your interrupt code here ... */
	GPIOA_PDOR |= 0x30000C00;   // all LEDs off
}
/* end of isr_usage_fault */


/*
** ===================================================================
**     Interrupt handler : isrINT_NMI
**
**     Description :
**         User interrupt service routine.
**     Parameters  : None
**     Returns     : Nothing
** ===================================================================
*/
void isrINT_NMI(void)
{
  /* Write your interrupt code here ... */
	GPIOA_PDOR |= 0x30000C00;   // all LEDs off
}
/* end of isrINT_NMI */

/*
** ===================================================================
**     Method      :  __init_hardware (component MK60N512MD100)
**
**     Description :
**         Initialization code for CPU core and a clock source.
** ===================================================================
*/
void __init_hardware(void)
{
  /*** ### MK60N512VMD100 "Cpu" init code ... ***/
  /*** PE initialization code after reset ***/
  SCB_VTOR = (uint32_t)__vector_table; /* Set the interrupt vector table position */
  /* Disable the WDOG module */
  /* WDOG_UNLOCK: WDOGUNLOCK=0xC520 */
  WDOG_UNLOCK = (uint16_t)0xC520U;     /* Key 1 */
  /* WDOG_UNLOCK : WDOGUNLOCK=0xD928 */
  WDOG_UNLOCK  = (uint16_t)0xD928U;    /* Key 2 */
  /* WDOG_STCTRLH: DISTESTWDOG=0,BYTESEL=0,TESTSEL=0,TESTWDOG=0,STNDBYEN=1,WAITEN=1,STOPEN=1,DBGEN=0,ALLOWUPDATE=1,WINEN=0,IRQRSTEN=0,CLKSRC=1,WDOGEN=0 */
  WDOG_STCTRLH = (uint16_t)0x01D2U;
  /* System clock initialization */
  /* Switch to FEI Mode */
  /* MCG_C1: CLKS=0,FRDIV=0,IREFS=1,IRCLKEN=1,IREFSTEN=0 */
  MCG_C1 = (uint8_t)0x06U;
  /* MCG_C2: RANGE=0,HGO=0,EREFS=0,LP=0,IRCS=0 */
  MCG_C2 = (uint8_t)0x00U;
  /* MCG_C4: DMX32=0,DRST_DRS=0 */		// FLL mit 20 - 25 MHz (FLL-Faktor 640)
  MCG_C4 &= (uint8_t)~(uint8_t)0xE0U;
  /* MCG_C4: DMX32=0,DRST_DRS=01 */		// FLL mit 40 - 50 MHz (FLL-Faktor 1280)
//  MCG_C4 |= (uint8_t)0x20U;				// funktioniert! 20.09.11 HL

/* Achtung: ueber 50 MHz Prescaler fuer Flash (OUTDIV4) von 2 auf 4 aendern,  !!!!!!!!!!!!!!!!!!!
 *                       Prescaler fuer Bus (OUTDIV2) und Flexbus (OUTDIV3) von 1 auf 2 aendern
 */
  /* MCG_C4: DMX32=0,DRST_DRS=10 */		// FLL mit 60 - 75 MHz (FLL-Faktor 1920)
//  MCG_C4 |= (uint8_t)0x40U;				// funktioniert! 26.09.11 HL
  /* MCG_C4: DMX32=0,DRST_DRS=11 */		// FLL mit 80 - 100 MHz (FLL-Faktor 2560)
//  MCG_C4 |= (uint8_t)0x60U;				// funktioniert nicht! 26.09.11 HL
  /* OSC_CR: ERCLKEN=0,EREFSTEN=0,SC2P=0,SC4P=0,SC8P=0,SC16P=0 */
  OSC_CR = (uint8_t)0x00U;
  /* SIM_SOPT2: MCGCLKSEL=0 */
  SIM_SOPT2 &= (uint8_t)~(uint8_t)0x01U;
  /* MCG_C5: PLLCLKEN=0,PLLSTEN=0,PRDIV=0 */
  MCG_C5 = (uint8_t)0x00U;
  /* MCG_C6: LOLIE=0,PLLS=0,CME=0,VDIV=0 */
  MCG_C6 = (uint8_t)0x00U;
  while((MCG_S & MCG_S_IREFST_MASK) == 0x00U) { /* Check that the source of the FLL reference clock is the internal reference clock. */
  }
  while((MCG_S & 0x0CU) != 0x00U) {    /* Wait until output of the FLL is selected */
  }
  /* SIM_CLKDIV1: OUTDIV1=1,OUTDIV2=1,OUTDIV3=1,OUTDIV4=3
   * d. h. Core/system clock = MCGOUTCLK/2;
   * Bus clock and FexBus clocks = MCGOUTCLK/2
   * Flash clock = MCGOUTCLK/4
   * At FLL clock 20 - 25 MHz, CPU and buses run with 10 - 12 MHz, Flash at 5 - 6 Mhz.*/
  SIM_CLKDIV1 = (uint32_t)0x11130000UL; /* Update system prescalers */


  /* SIM_CLKDIV1: OUTDIV1=0,OUTDIV2=1,OUTDIV3=1,OUTDIV4=3
   * d. h. Core/system clock = MCGOUTCLK/1;
   * Bus clock und FexBus clocks = MCGOUTCLK/2
   * Flash clock = MCGOUTCLK/4*/
//  SIM_CLKDIV1 = (uint32_t)0x01130000UL; /* Update system prescalers */
  /* SIM_CLKDIV1: OUTDIV1=0,OUTDIV2=0,OUTDIV3=1,OUTDIV4=1
   * d. h. Core/system clocks und Bus clock = MCGOUTCLK/1; FexBus und Flash clock = MCGOUTCLK/2*/
//  SIM_CLKDIV1 = (uint32_t)0x00110000UL; /* Update system prescalers */
  /* SIM_CLKDIV2: USBDIV=0,USBFRAC=1 */
  SIM_CLKDIV2 = (uint32_t)((SIM_CLKDIV2 & (uint32_t)~0x0EUL) | (uint32_t)0x01UL); /* Update USB clock prescalers */
  /* SIM_SOPT2: PLLFLLSEL=0 */
  SIM_SOPT2 &= (uint32_t)~0x00010000UL; /* Select FLL as a clock source for various peripherals */
  /* SIM_SOPT1: OSC32KSEL=0 */
  SIM_SOPT1 &= (uint32_t)~0x00080000UL; /* System oscillator drives 32 kHz clock for various peripherals */


// Ausser den drei Watchdog-Abschaltbefehlen ist das SIM_SCGC5-Register die einzige Konfiguration,
//   die notwendig ist, weil der Port mit den LEDs sonst keinen Takt hat.
//   Die CPU läuft dann ohne die restliche Taktinitialisierung mit 20 bis 25 MHz.
  /* SIM_SCGC5: PORTA=1 */
  SIM_SCGC5 |= (uint32_t)0x0200UL;     /* Enable clock gate for ports to enable pin routing */
}

/*
** ===================================================================
**     Method      :  MCU_init (component MK60N512MD100)
**
**     Description :
**         Device initialization code for selected peripherals.
** ===================================================================
*/
void MCU_init(void)
{
  /* PORTA_PCR4: ISF=0,MUX=7 */
//  PORTA_PCR4 = (uint32_t)((PORTA_PCR4 & (uint32_t)~0x01000000UL) | (uint32_t)0x0700UL);
  /* PORTA_PCR2: ISF=0,MUX=7 */
//  PORTA_PCR2 = (uint32_t)((PORTA_PCR2 & (uint32_t)~0x01000000UL) | (uint32_t)0x0700UL);
  /* PORTA_PCR1: ISF=0,MUX=7 */
//  PORTA_PCR1 = (uint32_t)((PORTA_PCR1 & (uint32_t)~0x01000000UL) | (uint32_t)0x0700UL);
  /* PORTA_PCR0: ISF=0,MUX=7 */
//  PORTA_PCR0 = (uint32_t)((PORTA_PCR0 & (uint32_t)~0x01000000UL) | (uint32_t)0x0700UL);
  /* PORTA_PCR3: ISF=0,MUX=7 */
//  PORTA_PCR3 = (uint32_t)((PORTA_PCR3 & (uint32_t)~0x01000000UL) | (uint32_t)0x0700UL);
  /* PORTA_PCR5: ISF=0,MUX=7 */
//  PORTA_PCR5 = (uint32_t)((PORTA_PCR5 & (uint32_t)~0x01000000UL) | (uint32_t)0x0700UL);
  /* SIM_SOPT6: RSTFLTEN=0,RSTFLTSEL=0 */
//  SIM_SOPT6 = (uint32_t)0x00UL;        /* Set reset pin filter */
  /* SIM_SCGC7: MPU=1 */
//  SIM_SCGC7 |= (uint32_t)0x04UL;                       
  /* Initialization of the MPU module */
  /* MPU_CESR: SPERR=0,VLD=0 */
//  MPU_CESR &= (uint32_t)~0xF8000001UL;                      
  /* MPU_RGDAAC0: M5RE=0,M5WE=0,M4RE=0,M4WE=0,M3SM=3,M3UM=0,M2SM=3,M2UM=7,M1SM=3,M1UM=7,M0SM=3,M0UM=7 */
//  MPU_RGDAAC0 = (uint32_t)((MPU_RGDAAC0 & (uint32_t)~0x0F1C0000UL) | (uint32_t)0x0061F7DFUL);
  /* MPU_RGD1_WORD3: VLD=0 */
//  MPU_RGD1_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD2_WORD3: VLD=0 */
//  MPU_RGD2_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD3_WORD3: VLD=0 */
//  MPU_RGD3_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD4_WORD3: VLD=0 */
//  MPU_RGD4_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD5_WORD3: VLD=0 */
//  MPU_RGD5_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD6_WORD3: VLD=0 */
//  MPU_RGD6_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD7_WORD3: VLD=0 */
//  MPU_RGD7_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD8_WORD3: VLD=0 */
//  MPU_RGD8_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD9_WORD3: VLD=0 */
//  MPU_RGD9_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD10_WORD3: VLD=0 */
//  MPU_RGD10_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_RGD11_WORD3: VLD=0 */
//  MPU_RGD11_WORD3 &= (uint32_t)~0x01UL;                      
  /* MPU_CESR: SPERR=0,VLD=1 */
//  MPU_CESR = (uint32_t)((MPU_CESR & (uint32_t)~0xF8000000UL) | (uint32_t)0x01UL);
  /* Initialization of the PMC module */
  /* PMC_LVDSC1: LVDACK=1,LVDIE=0,LVDRE=1,LVDV=0 */
//  PMC_LVDSC1 = (uint8_t)((PMC_LVDSC1 & (uint8_t)~(uint8_t)0x23U) | (uint8_t)0x50U);
  /* PMC_LVDSC2: LVWACK=1,LVWIE=0,LVWV=0 */
//  PMC_LVDSC2 = (uint8_t)((PMC_LVDSC2 & (uint8_t)~(uint8_t)0x23U) | (uint8_t)0x40U);
  /* PMC_REGSC: TRAMPO=0,BGBE=0 */
//  PMC_REGSC &= (uint8_t)~(uint8_t)0x13U;                           
  /* MC_PMPROT: AVLP=0,ALLS=0,AVLLS3=0,AVLLS2=0,AVLLS1=0 */
//  MC_PMPROT = (uint8_t)0x00U;          /* Setup Power mode protection register */
  /* Common initialization of the CPU registers */
  /* NVICIP20: PRI20=0 */
//  NVICIP20 = (uint8_t)0x00U;                             
  /* ### */
} /* MCU_init */

typedef void (*const tIsrFunc)(void);
typedef struct {
  uint32_t * __ptr;
  tIsrFunc __fun[119];
} tVectorTable;

/* Interrupt vector table */
static tVectorTable __vect_table __attribute__ ((section (".vectortable"))) = {
   (uint32_t *)__SP_INIT,               /* 0 (0x00000000) (prior: -) !< Initial stack pointer */
  {
   (tIsrFunc)&main,                     /* 1 (0x00000004) (prior: -) !< Initial program counter */
   (tIsrFunc)&isrINT_NMI,               /* 2 (0x00000008) (prior: -2) !< Non-maskable interrupt */
   (tIsrFunc)&isr_hard_fault,                /* 3 (0x0000000C) (prior: -1) !< Hard fault exception */
   (tIsrFunc)&isr_error,                /* 4 (0x00000010) (prior: -) !< Reserved interrupt 4 */
   (tIsrFunc)&isr_bus_error,                /* 5 (0x00000014) (prior: -) !< Bus fault exception */
   (tIsrFunc)&isr_usage_fault,                /* 6 (0x00000018) (prior: -) !< Usage fault exception */
   (tIsrFunc)&isr_error,                /* 7 (0x0000001C) (prior: -) !< Reserved interrupt 7 */
   (tIsrFunc)&isr_error,                /* 8 (0x00000020) (prior: -) !< Reserved interrupt 8 */
   (tIsrFunc)&isr_error,                /* 9 (0x00000024) (prior: -) !< Reserved interrupt 9 */
   (tIsrFunc)&isr_error,                /* 10 (0x00000028) (prior: -) !< Reserved interrupt 10 */
   (tIsrFunc)&isr_error,                /* 11 (0x0000002C) (prior: -) !< A supervisor call exception */
   (tIsrFunc)&isr_error,                /* 12 (0x00000030) (prior: -) !< Debug Monitor */
   (tIsrFunc)&isr_error,                /* 13 (0x00000034) (prior: -) !< Reserved interrupt 13 */
   (tIsrFunc)&isr_error,                /* 14 (0x00000038) (prior: -) !< PendSV exception - request for system level service */
   (tIsrFunc)&isr_error,                /* 15 (0x0000003C) (prior: -) !< SysTick Interrupt */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 16 (0x00000040) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 17 (0x00000044) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 18 (0x00000048) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 19 (0x0000004C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 20 (0x00000050) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 21 (0x00000054) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 22 (0x00000058) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 23 (0x0000005C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 24 (0x00000060) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 25 (0x00000064) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 26 (0x00000068) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 27 (0x0000006C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 28 (0x00000070) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 29 (0x00000074) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 30 (0x00000078) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 31 (0x0000007C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 32 (0x00000080) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 33 (0x00000084) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 34 (0x00000088) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 35 (0x0000008C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 36 (0x00000090) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 37 (0x00000094) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 38 (0x00000098) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 39 (0x0000009C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 40 (0x000000A0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 41 (0x000000A4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 42 (0x000000A8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 43 (0x000000AC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 44 (0x000000B0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 45 (0x000000B4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 46 (0x000000B8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 47 (0x000000BC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 48 (0x000000C0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 49 (0x000000C4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 50 (0x000000C8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 51 (0x000000CC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 52 (0x000000D0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 53 (0x000000D4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 54 (0x000000D8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 55 (0x000000DC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 56 (0x000000E0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 57 (0x000000E4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 58 (0x000000E8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 59 (0x000000EC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 60 (0x000000F0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 61 (0x000000F4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 62 (0x000000F8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 63 (0x000000FC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 64 (0x00000100) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 65 (0x00000104) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 66 (0x00000108) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 67 (0x0000010C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 68 (0x00000110) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 69 (0x00000114) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 70 (0x00000118) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 71 (0x0000011C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 72 (0x00000120) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 73 (0x00000124) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 74 (0x00000128) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 75 (0x0000012C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 76 (0x00000130) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 77 (0x00000134) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 78 (0x00000138) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 79 (0x0000013C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 80 (0x00000140) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 81 (0x00000144) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 82 (0x00000148) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 83 (0x0000014C) (prior: -) */
   (tIsrFunc)&PIT_CH0_INT,                                 /* 84 (0x00000150) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 85 (0x00000154) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 86 (0x00000158) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 87 (0x0000015C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 88 (0x00000160) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 89 (0x00000164) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 90 (0x00000168) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 91 (0x0000016C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 92 (0x00000170) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 93 (0x00000174) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 94 (0x00000178) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 95 (0x0000017C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 96 (0x00000180) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 97 (0x00000184) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 98 (0x00000188) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 99 (0x0000018C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 100 (0x00000190) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 101 (0x00000194) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 102 (0x00000198) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 103 (0x0000019C) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 104 (0x000001A0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 105 (0x000001A4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 106 (0x000001A8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 107 (0x000001AC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 108 (0x000001B0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 109 (0x000001B4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 110 (0x000001B8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 111 (0x000001BC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 112 (0x000001C0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 113 (0x000001C4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 114 (0x000001C8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 115 (0x000001CC) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 116 (0x000001D0) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 117 (0x000001D4) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR,                              /* 118 (0x000001D8) (prior: -) */
   (tIsrFunc)&UNASSIGNED_ISR                               /* 119 (0x000001DC) (prior: -) */
  }
};
